@@ -333,7 +333,7 @@ class H5_DLLCPP H5Location : public IdComponent {
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
     // Noop destructor.
-    virtual ~H5Location() override;
+    virtual ~H5Location() override = default;
 
 }; // end of H5Location
 } // namespace H5
