@@ -31,16 +31,26 @@
 /*****************/
 
 /* Macros defining operation IDs for map VOL callbacks (implemented using the
- * "optional" VOL callback) */
-#define H5VL_MAP_CREATE   1 /**< Callback operation ID for map create */
-#define H5VL_MAP_OPEN     2 /**< Callback operation ID for map open */
-#define H5VL_MAP_GET_VAL  3 /**< Callback operation ID for getting an associated value from a map */
-#define H5VL_MAP_EXISTS   4 /**< Callback operation ID for checking if a value exists in a map */
-#define H5VL_MAP_PUT      5 /**< Callback operation ID for putting a key-value pair to a map */
-#define H5VL_MAP_GET      6 /**< Callback operation ID for map get callback */
-#define H5VL_MAP_SPECIFIC 7 /**< Callback operation ID for map specific operation */
-#define H5VL_MAP_OPTIONAL 8 /**< Currently unused */
-#define H5VL_MAP_CLOSE    9 /**< Callback operation ID for terminating access to a map */
+ * "optional" VOL callback)
+ */
+/** Callback operation ID for map create \since 1.12.0 */
+#define H5VL_MAP_CREATE 1
+/** Callback operation ID for map open \since 1.12.0 */
+#define H5VL_MAP_OPEN 2
+/** Callback operation ID for getting an associated value from a map \since 1.12.0 */
+#define H5VL_MAP_GET_VAL 3
+/** Callback operation ID for checking if a value exists in a map \since 1.12.0 */
+#define H5VL_MAP_EXISTS 4
+/** Callback operation ID for putting a key-value pair to a map \since 1.12.0 */
+#define H5VL_MAP_PUT 5
+/** Callback operation ID for map get callback \since 1.12.0 */
+#define H5VL_MAP_GET 6
+/** Callback operation ID for map specific operation \since 1.12.0 */
+#define H5VL_MAP_SPECIFIC 7
+/** Currently unused \since 1.12.0 */
+#define H5VL_MAP_OPTIONAL 8
+/** Callback operation ID for terminating access to a map \since 1.12.0 */
+#define H5VL_MAP_CLOSE 9
 
 /*******************/
 /* Public Typedefs */
@@ -50,19 +60,23 @@
  * Types for map GET callback
  */
 typedef enum H5VL_map_get_t {
-    H5VL_MAP_GET_MAPL,     /**< Callback operation ID for getting map access property list   */
-    H5VL_MAP_GET_MCPL,     /**< Callback operation ID for getting map creation property list */
-    H5VL_MAP_GET_KEY_TYPE, /**< Callback operation ID for getting the key datatype for a map */
-    H5VL_MAP_GET_VAL_TYPE, /**< Callback operation ID for getting the value datatype for a map */
-    H5VL_MAP_GET_COUNT /**< Callback operation ID for getting the number of key-value pairs stored in a map */
+    H5VL_MAP_GET_MAPL,     /**< Callback operation ID for getting map access property list   \since 1.12.0 */
+    H5VL_MAP_GET_MCPL,     /**< Callback operation ID for getting map creation property list \since 1.12.0 */
+    H5VL_MAP_GET_KEY_TYPE, /**< Callback operation ID for getting the key datatype for a map \since 1.12.0 */
+    H5VL_MAP_GET_VAL_TYPE, /**< Callback operation ID for getting the value datatype for a map \since 1.12.0
+                            */
+    H5VL_MAP_GET_COUNT /**< Callback operation ID for getting the number of key-value pairs stored in a map
+                          \since 1.12.0 */
 } H5VL_map_get_t;
 
 /**
  * Types for map SPECIFIC callback
  */
 typedef enum H5VL_map_specific_t {
-    H5VL_MAP_ITER,  /**< Callback operation ID for iterating over all key-value pairs stored in the map */
-    H5VL_MAP_DELETE /**< Callback operation ID for deleting a key-value pair stored in the map */
+    H5VL_MAP_ITER,  /**< Callback operation ID for iterating over all key-value pairs stored in the map
+                       \since 1.12.0 */
+    H5VL_MAP_DELETE /**< Callback operation ID for deleting a key-value pair stored in the map \since 1.12.0
+                     */
 } H5VL_map_specific_t;
 
 //! <!-- [H5M_iterate_t_snip] -->
@@ -214,7 +228,7 @@ extern "C" {
  * \lcpl_id
  * \mcpl_id
  * \mapl_id
- * \returns \hid_t{map object}
+ * \return \hid_t{map object}
  *
  * \details H5Mcreate() creates a new map object for storing key-value
  *          pairs. The in-file datatype for keys is defined by \p key_type_id
@@ -238,16 +252,34 @@ H5_DLL hid_t H5Mcreate_async(const char *app_file, const char *app_func, unsigne
                              const char *name, hid_t key_type_id, hid_t val_type_id, hid_t lcpl_id,
                              hid_t mcpl_id, hid_t mapl_id, hid_t es_id);
 #else
-H5_DLL hid_t  H5Mcreate_async(hid_t loc_id, const char *name, hid_t key_type_id, hid_t val_type_id,
-                              hid_t lcpl_id, hid_t mcpl_id, hid_t mapl_id, hid_t es_id);
+H5_DLL hid_t H5Mcreate_async(hid_t loc_id, const char *name, hid_t key_type_id, hid_t val_type_id,
+                             hid_t lcpl_id, hid_t mcpl_id, hid_t mapl_id, hid_t es_id);
 #endif
 
 /**
  * \ingroup H5M
  *
- * \brief
+ * \brief Creates a map object without linking it into a file
  *
- * \details
+ * \fgdta_loc_id
+ * \type_id{key_type_id}
+ * \type_id{val_type_id}
+ * \mcpl_id
+ * \mapl_id
+ * \return \hid_t{map object}
+ *          The resulting ID should be linked into the file with H5Olink or it
+ *          will be deleted when closed.
+ *
+ * \details H5Mcreate_anon() creates a new map object for storing key-value
+ *          pairs. The in-file datatype for keys is defined by \p key_type_id
+ *          and the in-file datatype for values is defined by \p val_type_id. \p
+ *          loc_id specifies the file to create the map object, but no link to
+ *          the object is created.  Other options can be specified through the
+ *          property lists \p mcpl_id and \p mapl_id.
+ *
+ *          The new map should be linked into the group hierarchy before being
+ *          closed or it will be deleted. The map should be closed when the
+ *          caller no longer requires it.
  *
  * \since 1.12.0
  *
@@ -262,7 +294,7 @@ H5_DLL hid_t H5Mcreate_anon(hid_t loc_id, hid_t key_type_id, hid_t val_type_id,
  * \fgdta_loc_id{loc_id}
  * \param[in] name Map object name relative to \p loc_id
  * \mapl_id
- * \returns \hid_t{map object}
+ * \return \hid_t{map object}
  *
  * \details H5Mopen() finds a map object specified by \p name under the location
  *          specified by \p loc_id. The map object should be close with
@@ -282,7 +314,7 @@ H5_DLL hid_t H5Mopen(hid_t loc_id, const char *name, hid_t mapl_id);
 H5_DLL hid_t H5Mopen_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
                            const char *name, hid_t mapl_id, hid_t es_id);
 #else
-H5_DLL hid_t  H5Mopen_async(hid_t loc_id, const char *name, hid_t mapl_id, hid_t es_id);
+H5_DLL hid_t H5Mopen_async(hid_t loc_id, const char *name, hid_t mapl_id, hid_t es_id);
 #endif
 
 /**
@@ -291,7 +323,7 @@ H5_DLL hid_t  H5Mopen_async(hid_t loc_id, const char *name, hid_t mapl_id, hid_t
  * \brief Terminates access to a map object
  *
  * \map_id
- * \returns \herr_t
+ * \return \herr_t
  *
  * \details H5Mclose() closes access to a map object specified by \p map_id and
  *          releases resources used by it.
@@ -321,7 +353,7 @@ H5_DLL herr_t H5Mclose_async(hid_t map_id, hid_t es_id);
  * \brief Gets key datatype for a map object
  *
  * \map_id
- * \returns \hid_t{datatype}
+ * \return \hid_t{datatype}
  *
  * \details H5Mget_key_type() retrieves key datatype as stored in the file for a
  *          map object specified by \p map_id and returns identifier for the
@@ -338,7 +370,7 @@ H5_DLL hid_t H5Mget_key_type(hid_t map_id);
  * \brief Gets value datatype for a map object
  *
  * \map_id
- * \returns \hid_t{datatype}
+ * \return \hid_t{datatype}
  *
  * \details H5Mget_val_type() retrieves value datatype as stored in the file for
  *          a map object specified by \p map_id and returns identifier for the
@@ -355,7 +387,7 @@ H5_DLL hid_t H5Mget_val_type(hid_t map_id);
  * \brief Gets creation property list for a map object
  *
  * \map_id
- * \returns \hid_t{map creation property list}
+ * \return \hid_t{map creation property list}
  *
  * \details H5Mget_create_plist() returns an identifier for a copy of the
  *          creation property list for a map object specified by \p map_id.
@@ -374,7 +406,7 @@ H5_DLL hid_t H5Mget_create_plist(hid_t map_id);
  * \brief Gets access property list for a map object
  *
  * \map_id
- * \returns \hid_t{map access property list}
+ * \return \hid_t{map access property list}
  *
  * \details H5Mget_access_plist() returns an identifier for a copy of the access
  *          property list for a map object specified by \p map_id.
@@ -392,7 +424,7 @@ H5_DLL hid_t H5Mget_access_plist(hid_t map_id);
  * \map_id
  * \param[out] count The number of key-value pairs stored in the map object
  * \dxpl_id
- * \returns \herr_t
+ * \return \herr_t
  *
  * \details H5Mget_count() retrieves the number of key-value pairs stored in a
  *          map specified by map_id.
@@ -413,7 +445,7 @@ H5_DLL herr_t H5Mget_count(hid_t map_id, hsize_t *count, hid_t dxpl_id);
  * \type_id{val_mem_type_id}
  * \param[in] value Pointer to value buffer
  * \dxpl_id
- * \returns \herr_t
+ * \return \herr_t
  *
  * \details H5Mput() adds a key-value pair to a map object specified by \p
  *          map_id, or updates the value for the specified key if one was set
@@ -457,7 +489,7 @@ H5_DLL herr_t H5Mput_async(hid_t map_id, hid_t key_mem_type_id, const void *key,
  * \type_id{val_mem_type_id}
  * \param[out] value Pointer to value buffer
  * \dxpl_id
- * \returns \herr_t
+ * \return \herr_t
  *
  * \details H5Mget() retrieves from a map object specified by \p map_id, the
  *          value associated with the provided key \p key. \p key_mem_type_id
@@ -502,7 +534,7 @@ H5_DLL herr_t H5Mget_async(hid_t map_id, hid_t key_mem_type_id, const void *key,
  * \param[in] key Pointer to key buffer
  * \param[out] exists Pointer to a buffer to return the existence status
  * \dxpl_id
- * \returns \herr_t
+ * \return \herr_t
  *
  * \details H5Mexists() checks if the provided key is stored in the map object
  *          specified by \p map_id. If \p key_mem_type_id is different from that
@@ -528,7 +560,7 @@ H5_DLL herr_t H5Mexists(hid_t map_id, hid_t key_mem_type_id, const void *key, hb
  * \param[in] op User-defined iterator function
  * \op_data
  * \dxpl_id
- * \returns \herr_t
+ * \return \herr_t
  *
  * \details H5Miterate() iterates over all key-value pairs stored in the map
  *          object specified by \p map_id, making the callback specified by \p
@@ -553,6 +585,8 @@ H5_DLL herr_t H5Mexists(hid_t map_id, hid_t key_mem_type_id, const void *key, hb
  *  \warning Adding or removing key-value pairs to the map during iteration
  *           will lead to undefined behavior.
  *
+ * \callback_note
+ *
  * \since 1.12.0
  *
  */
@@ -572,7 +606,7 @@ H5_DLL herr_t H5Miterate(hid_t map_id, hsize_t *idx, hid_t key_mem_type_id, H5M_
  * \op_data
  * \dxpl_id
  * \lapl_id
- * \returns \herr_t
+ * \return \herr_t
  *
  * \details H5Miterate_by_name() iterates over all key-value pairs stored in the
  *          map object specified by \p map_id, making the callback specified by
@@ -597,6 +631,8 @@ H5_DLL herr_t H5Miterate(hid_t map_id, hsize_t *idx, hid_t key_mem_type_id, H5M_
  *  \warning Adding or removing key-value pairs to the map during iteration
  *           will lead to undefined behavior.
  *
+ * \callback_note
+ *
  * \since 1.12.0
  *
  */
@@ -612,7 +648,7 @@ H5_DLL herr_t H5Miterate_by_name(hid_t loc_id, const char *map_name, hsize_t *id
  * \type_id{key_mem_type_id}
  * \param[in] key Pointer to key buffer
  * \dxpl_id
- * \returns \herr_t
+ * \return \herr_t
  *
  * \details H5Mdelete() deletes a key-value pair from the map object specified
  *          by \p map_id. \p key_mem_type_id specifies the datatype for the
