@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -17,8 +16,9 @@
  * fill this file with lots of gunk...
  */
 
-#ifndef _HDF5_HL_H
-#define _HDF5_HL_H
+#ifndef HDF5_HL_H
+#define HDF5_HL_H
+
 #include "hdf5.h"       /* hdf5 main library */
 #include "H5DOpublic.h" /* dataset optimization */
 #include "H5DSpublic.h" /* dimension scales */
@@ -28,5 +28,4 @@
 #include "H5PTpublic.h" /* packet table */
 #include "H5LDpublic.h" /* lite dataset */
 
-#endif /*H5_INCLUDE_HL*/
-
+#endif /*HDF5_HL_H*/
